/* Projeto: Sistema de locadora online.
*
* Tipo: Cliente.
*
*/

package br.ufpe.lp3.locadora.cliente;

import br.ufpe.lp3.locadora.util.*;


/**
* Esta classe modela um Cliente.
*
* @author: Maurikleber Modified by Helder
*
* @copyright: Larcio, Maurikleber, Helder, Hlio
*/
public class Cliente {


    private String nome;             //nome do cliente
    private String codigo;           //codigo do cliente
    private Endereco endereco;       //endereco
    private String identidade;   //identidade
    private String orgao;    //orgao expeditor da identidade do cliente
    private String uf;       //o estado em que foi emitida a identidade
    private String cpf;              //cpf (chave unica)
    private String telefone;         //telefone cliente
    private String celular;          //celular do cliente
    private boolean inadimplente;    //indica se cliente estah em debito

    /**
    * Primeiro construtor da classe cliente
    *
    * @param nome
    * @param cpf
    *
    */
    public Cliente( String nome , String cpf){
        this.nome = nome;
        this.endereco = new Endereco();
        this.identidade = "";
        this.orgao = "";
        this.uf = "";
        this.cpf = cpf;
        this.telefone = "";
        this.celular = "";
        this.codigo = "";
    }

    /**
    * Segundo construtor da classe Cliente
    *
    * @param nome
    * @param cpf
    * @param identidade
    * @param orgao
    * @param uf
    * @param endereco
    * @param telefone
    * @param celular
    * @param codigo
    *
    */
    public Cliente( String nome , String cpf, String identidade, String orgao,
                    String uf, Endereco endereco, String telefone,
                    String celular, String codigo ){
        this.nome = nome;
        this.endereco = endereco;
        this.cpf = cpf;
        this.identidade = identidade;
        this.orgao = orgao;
        this.uf = uf;
        this.telefone = telefone;
        this.celular  = celular;
        this.codigo = codigo;
    }

    /**
    * Este metodo converte alguns valores de atributos para Strings e
    * concatena-os
    *
    * @param
    * @return       Uma String descrevendo o objeto referenciado
    */
    public String toString(){
        return  "\nnome: " + nome + "\ncpf: " + cpf + "\nidentidade: "
                + identidade + "\nOrgao Expeditor: " + orgao +
                "\nUnidade Federal: " + uf + "\nEndereco: " + endereco +
                "\n\ntelfone: " + telefone + "\nCelular: " + celular +
                "\ncodigo: " + codigo + "\n";
    }

    /**
    * Retorna o nome do cliente
    *
    * @return    Uma String contendo o nome do cliente
    */
    public String getNome(){
        return this.nome;
    }

    /**
    * Ajusta o nome do cliente
    *
    * @param    Uma String contendo o nome do cliente
    */
    public void setNome(String nome){
        this.nome = nome;
    }

    /**
    * Retorna codigo de cliente
    *
    * @return Uma String contento  codigo
    */
    public String getCodigo(){
        return this.codigo;
    }

    /**
    * Este metodo ajusta codigo cliente
    *
    *@param  Um String  contendo codigo
    */
    public void setCodigo(String codigo){
        this.codigo = codigo;
    }

    /**
    * Este metodo retorna o celular do cliente
    *
    *@return  Um String contendo numero de celular
    */
    public String getCelular(){
        return this.celular;
    }

    /**
    *Este metodo ajusta o numero do celular de um cliente
    *
    *@param Um String contendo um numero de celular
    */
    public void setCelular(String celular){
        this.celular = celular;
    }

    /**
    * Este metodo ajusta o numero do telefone de  um cliente
    *
    *@param  Um String contendo telefone do cliente
    */
    public void setTelefone(String telefone){
        this.telefone = telefone;
    }

    /**
    * Este metodo retorna o telefone do cliente
    *
    *@return  Um String contendo numero de telefone
    */
    public String getTelefone(){
        return this.telefone;
    }

    /**
    * Este metodo retorna cpf do cliente
    *
    *@return  Um String contendo cpf do cliente
    */
    public String getCpf(){
        return this.cpf;
    }

    /**
    * Este metodo ajusta cpf do cliente
    *
    *@param  Um String contendo cpf do cliente
    */
    public void setCpf(String cpf){
        this.cpf = cpf;
    }

    /**
    * Este metodo retorna cpf do cliente
    *
    *@return  Um String contendo cpf do cliente
    */
    public String getIdentidade(){
        return this.identidade;
    }

    /**
    * Este metodo ajusta cpf do cliente
    *
    *@param  Um String contendo cpf do cliente
    */
    public void setIdentidade(String identidade){
        this.identidade = identidade;
    }

    /**
    * Este metodo retorna cpf do cliente
    *
    *@return  Um String contendo cpf do cliente
    */
    public String getOrgao(){
        return this.orgao;
    }

    /**
    * Este metodo ajusta cpf do cliente
    *
    *@param  Um String contendo cpf do cliente
    */
    public void setOrgao(String orgao){
        this.orgao = orgao;
    }

    /**
    * Este metodo retorna cpf do cliente
    *
    *@return  Um String contendo cpf do cliente
    */
    public String getUf(){
        return this.uf;
    }

    /**
    * Este metodo ajusta cpf do cliente
    *
    *@param  Um String contendo cpf do cliente
    */
    public void setUf(String uf){
        this.uf = uf;
    }

    /**
    * Este metodo retorna um endereco completo do cliente
    *
    *@return Um Endereco completo do cliente
    */
    public Endereco getEndereco(){
        return this.endereco;
    }

    /**
    * Este metodo ajusta um novo endereco para o cliente
    * o endereco sera muda completamente e nao por campos
    *
    *@param  Um Endereco completo do cliente
    */
    public void setEndereco(Endereco endereco){
        this.endereco = endereco;
    }
}


