/*Projeto de sistema de locadora
*
*Tipo:  RepositorioClientesArray
*
*/

package br.ufpe.lp3.locadora.cliente;

import java.util.Calendar;
import java.util.GregorianCalendar;
import br.ufpe.lp3.locadora.cliente.*;
import br.ufpe.lp3.locadora.util.*;


/**
* Esta classe modela um Repositorio de clientes.
*
* @author: Maurikleber
*
* @copyright: Larcio, Maurikleber, Helder, Hlio
*/
public class RepositorioClientesArray implements IRepositorioClientes {


    private final int MAXIMO  = 100;    //numero maximo de clientes
    private int indice;                 // percorrer o array
    private int interador;              //usada nos metodos de interacao
    private Cliente[] arrayClientes;    // array  dos clientes

    /**
    * construtor da classe cliente
    *
    * @param indice
    * @param interador
    */
    public RepositorioClientesArray() {
        indice = 0;
        interador = 0;
        arrayClientes = new Cliente [MAXIMO];
    }

    /**
    * Este metodo verifica se um determiando cliente existe
    *
    * Limitacoes: o campo cpf identifica um cliente de forma unica
    *             determinando portanto sua existencia,ou seja
    *             um determinado cliente existe se no repositorio
    *             consta o seu cpf e codigo,nao importando os demais dados
    * @param Um Cliente a ser verificado se consta no array
    *
    * @return Um boolean ,onde true significa que cliente existe
    */
    public boolean existeCliente(Cliente cliente) {
           int i;
           boolean existe = false;
           for (i=0; i < indice; i++) {
               if (arrayClientes[i].equals(cliente)) {
                   existe = true;
               }
           } return existe;
    }

    /**
    * Este metodo inseri um cliente no repositorio
    *
    *@param Um Cliente  a ser inserido
    */
    public void cadastrarCliente(Cliente cliente) throws ClienteExistenteException{
        Cliente[] arraytemp;

        if (indice == arrayClientes.length){
            arraytemp = arrayClientes;
            arrayClientes = new Cliente[2 * MAXIMO];
            for ( int i = 0; i < arraytemp.length ; i++){
                arrayClientes[i] = arraytemp[i];
            }
        }
        if (indice == 0){
            arrayClientes[indice] = cliente;
            indice++;
        } else if (! existeCliente(cliente)){
            arrayClientes[indice] = cliente;
            indice++;
        }
    }

    /**
    * este metodo procura um cliente por codigo
    * qualquer modificacao nos clientes retornados
    * por esse metodo gera mudanca no repositorio
    *
    * Limitacoes: O metodo retornara um repositorio null se nao encontrar
    * um certo cliente,ou seja se ele nao existir
    *
    *@param Um String contendo codigo do cliente
    *
    *@return  Um Repositorio de Clientes com mesmo codigo
    */
    public RepositorioClientesArray procurarCliente(String codigo)
      throws ClienteInexistenteException {

        int tam = 0;
        RepositorioClientesArray clientesRetorno = null;
        int i = 0;
        while ( i < indice){
             if (arrayClientes[i].getCodigo().equals(codigo)){
                 clientesRetorno = new RepositorioClientesArray();
                 i = indice;
             } i++;
        }
        for (int j = 0; j < indice; j++){
            if (arrayClientes[j].getCodigo().equals(codigo)){
                clientesRetorno.cadastrarCliente(arrayClientes[j]);
            }
        } return clientesRetorno;
    }

    /**
    * Este metodo procura um Cliente pelo codigo e cpf(chave unica)
    * caso nao encontre um ele retornara um null
    *
    * @param Um String contendo codigo outro contendo cpf
    *
    * @return Um Cliente
    */
    public Cliente procurarCliente(String codigo, String cpf, String nome)
      throws ClienteInexistenteException {

        Cliente cliente = null;
        for (int i = 0; i < indice ; i++){
            if (arrayClientes[i].getCodigo().equals(codigo)){
                cliente = arrayClientes[i];
            }
        } return cliente; //acho que seria bom fazer um 'cast'
    }

    /**
    * Este metodo remove um cliente ,usando a chave unica cpf
    * caso este cliente ou cpf nao existam nada eh feito,ou melhor
    * nao eh preciso remover nada ,portando verificar a existencia
    * ou nao de um certo cliente nao importa para o metodo
    *
    *@param Um string contendo o cpf
    */
    public void removerCliente(String cpf) throws ClienteInexistenteException {
        for (int i = 0; i < indice ; i++){
            if (arrayClientes[i].getCpf().equals(cpf)){
                arrayClientes[i] = arrayClientes[indice - 1];
                arrayClientes[indice - 1] = null;
                indice--;
                if(indice <= 0){
                    indice = 0;
                }
            }
        } return;
    }

    /**
    * Este metodo atualiza os dados de um cliente
    * retornando true caso for bem sucessedida operacao
    * e false caso contrario
    *
    * Limitacoes: a variavel cpf eh chave unica por isso deve ser sempre
    *             pedida!e o metodo supoe que ela nunca sera alterada
    *             caso o cliente passado para o metodo nao exista no
    *             repositorio entao nada eh atualizado envia se um false
    *
    * @param  um Cliente
    *
    * @return um boolean
    */
    public boolean atualizarCliente(Cliente cliente) throws ClienteInexistenteException {
        boolean atualizado = false;
        for (int i = 0; i < indice; i++){
            if (arrayClientes[i].getCpf().equals(cliente.getCpf())){
                arrayClientes[i].setCpf(cliente.getCpf());
                arrayClientes[i].setCodigo(cliente.getCodigo());
                arrayClientes[i].setNome(cliente.getNome());
                arrayClientes[i].setEndereco(cliente.getEndereco());
                arrayClientes[i].setTelefone(cliente.getTelefone());
                arrayClientes[i].setCelular(cliente.getCelular());
                arrayClientes[i].setIdentidade(cliente.getIdentidade());
                arrayClientes[i].setOrgao(cliente.getOrgao());
                arrayClientes[i].setUf(cliente.getUf());
                atualizado = true;
            }
        } return atualizado;
    }

    /**
    * Este metodo fornece um interador para um conjunto de clientes
    *
    * @return interadorClientesArray
    */
    public InteradorClientesArray getInterador(){
        InteradorClientesArray interador = new InteradorClientesArray(arrayClientes);
        return interador;
    }
}
