package br.ufpe.lp3.locadora.util;

/**
 * <p>Title: Locadora OnLine </p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company:UFPE - CIN </p>
 * @author Hlio Jum Tonsho
 * @version 1.0
 */

import java.util.Calendar;
// import java.util.GregorianCalendar;



/**
 * Esta  uma classe que modela o periodo que o usuario permaneceu com produtos
 * da locadora.
 *
 * @see java.util.Calendar
 * @see java.util.GregorianCalendar
 *
 * @author		Larcio Dias
 */

public class Periodo {

	private Calendar dataInicial;       //A data da locacao, por exemplo
	private Calendar dataFinal;         //A data da devolucao, por exemplo

   /**
	* Construtor da classe Periodo
	*
	* @param dataInicial	Data inicial do periodo
	* @param dataFinal		Data final do periodo
	*/
	public Periodo(Calendar dataInicial, Calendar dataFinal) {
		if (dataInicial != null && dataFinal != null
                 && dataInicial.before(dataFinal) ){
				    this.dataInicial = dataInicial;
				    this.dataFinal = dataFinal;
		}
	}

   /**
    * Ajusta a data inicial do perodo.
    *
    * @param dataInicial	Data inicial
    */
	public void setDataInicial(Calendar dataInicial){
		if ((dataInicial != null)&&(dataInicial.before(this.dataFinal))){
			this.dataInicial = dataInicial;
	    }
    }

   /**
	* Retorna a data inicial
	*
	* @return dataInicial		A data inicial do periodo
	*/
	public Calendar getDataInicial() {
		return this.dataInicial;
	}

   /**
	* Ajusta a data final do perodo.
	*
	* @param dataFinal		    A data final do periodo
	*/
    public void setDataFinal(Calendar dataFinal){
		if ( (dataFinal != null)&&(dataFinal.after(this.dataInicial)) ){
				this.dataFinal = dataFinal;
		}
	}


   /**
    * Retorna a data final
    *
    * @return dataFinal		A data final do periodo
    */
	public Calendar getDataFinal() {
		return this.dataFinal;
	}

   /**
    * Calcula o numero de dias de um certo perodo
    *
    * @return numDias 	Numero de dias de um perodo
    */
	public int calculaNumeroDias() {
		int numDias;
		int ano1 = this.dataInicial.get(Calendar.YEAR);
		int diaAno1 = this.dataInicial.get(Calendar.DAY_OF_YEAR);
		int ano2 = this.dataFinal.get(Calendar.YEAR);
		int diaAno2 = this.dataFinal.get(Calendar.DAY_OF_YEAR);
		int deltaAno; // Diferena entre dois anos
		int maxDiasAno; // Quantidade maxima de dias d um ano

		if (ano1 == ano2) {
			numDias = diaAno2 - diaAno1;
		} else {
			deltaAno = ano2 - ano1;
			maxDiasAno = this.dataInicial.getActualMaximum(Calendar.DAY_OF_YEAR);
			numDias = (diaAno2 + (maxDiasAno * deltaAno) ) - diaAno1;
		}
		return numDias;
	}

  	/**
	 * Retorna a descrio do perodo, ou seja a data inicial e a final
	 *
	 * @return String		Descricao do perodo
	 */
	public String toString() {
		int dia1 = this.getDataInicial().get(Calendar.DATE);
		int dia2 = this.getDataFinal().get(Calendar.DATE);
		int mes1 = this.getDataInicial().get(Calendar.MONTH) + 1;
		int mes2 = this.getDataFinal().get(Calendar.MONTH) + 1;
		int ano1 = this.getDataInicial().get(Calendar.YEAR);
		int ano2 = this.getDataFinal().get(Calendar.YEAR);

		return ("Data inicial: " + dia1 + "/" + mes1 + "/" + ano1 +
                    " - Data Final" + dia2 + "/" + mes2 + "/" + ano2);
    }

}//Fim da classe Periodo